@@ -31,7 +31,7 @@ pub struct Args {
     /// The author email to use for the commit.
     ///
     /// [default: email from git, or else from parent commit, or else "save"]
-    #[clap(long)]
+    #[clap(long, short = 'e')]
     pub email: Option<String>,
 
     /// The target commit hash or prefix, in hex.
@@ -41,35 +41,35 @@ pub struct Args {
     pub hash_hex: Option<String>,
 
     /// Use a manual commit message instead of the default generated message.
-    #[clap(long, short)]
+    #[clap(long, short = 'm')]
     pub message: Option<String>,
 
     /// The author name to use for the commit.
     ///
     /// [default: name from git, or else from parent commit, or else "save"]
-    #[clap(long)]
+    #[clap(long, short = 'n')]
     pub name: Option<String>,
 
     /// The time is NOW.
     ///
     /// [default: the time is ACTUALLY now]
-    #[clap(long = "now")]
+    #[clap(long = "now", short = 'w')]
     pub now_seconds: Option<i64>,
 
     /// Decrease log verbosity. May be used multiple times.
-    #[clap(short, long, parse(from_occurrences))]
+    #[clap(long, short = 'q', parse(from_occurrences))]
     pub quiet: i32,
 
     /// Seconds of timestamp allocated for each commit to search.
-    #[clap(long="step", default_value_t = 64 * 2)]
+    #[clap(long="step", short='s', default_value_t = 64 * 2)]
     pub step_seconds: u32,
 
     /// Increase log verbosity. May be used multiple times.
-    #[clap(short, long, parse(from_occurrences))]
+    #[clap(long, short = 'v', parse(from_occurrences))]
     pub verbose: i32,
 
     /// Proceed in spite of any warnings.
-    #[clap(long, short)]
+    #[clap(long, short = 'y')]
     pub yes: bool,
 }
 
@@ -385,6 +385,7 @@ pub fn init() -> Args {
         tracing_subscriber::fmt()
             .with_env_filter(::tracing_subscriber::EnvFilter::new(log_level))
             .with_target(false)
+            .without_time()
             .with_span_events(
                 tracing_subscriber::fmt::format::FmtSpan::NEW
                     | tracing_subscriber::fmt::format::FmtSpan::CLOSE,
